Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(406)

Unified Diff: content/common/sandbox_linux/bpf_gpu_policy_linux.h

Issue 251183004: Linux GPU sandbox: only allocate broker policy in the broker. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/sandbox_linux/bpf_gpu_policy_linux.h
diff --git a/content/common/sandbox_linux/bpf_gpu_policy_linux.h b/content/common/sandbox_linux/bpf_gpu_policy_linux.h
index 496a39e65550799e5ae91461157770c96f3e25c7..6da4d04d30f9b2c95b89115c35535155acd48cf5 100644
--- a/content/common/sandbox_linux/bpf_gpu_policy_linux.h
+++ b/content/common/sandbox_linux/bpf_gpu_policy_linux.h
@@ -29,13 +29,13 @@ class GpuProcessPolicy : public SandboxBPFBasePolicy {
protected:
// Start a broker process to handle open() inside the sandbox.
// |broker_sandboxer_callback| is a callback that will enable a suitable
// sandbox for the broker process itself.
// |read_whitelist_extra| and |write_whitelist_extra| are lists of file
// names that should be whitelisted by the broker process, in addition to
// the basic ones.
void InitGpuBrokerProcess(
- const base::Callback<bool(void)>& broker_sandboxer_callback,
+ sandbox::SandboxBPFPolicy* (*broker_sandboxer_allocator)(void),
Jorge Lucangeli Obes 2014/04/28 23:43:53 It was nice to have base::Callback's instead of fu
jln (very slow on Chromium) 2014/04/28 23:53:18 We could still make it a CallBack if we really wan
const std::vector<std::string>& read_whitelist_extra,
@@ -29,13 +29,13 @@ class GpuProcessPolicy : public SandboxBPFBasePolicy {
protected:
// Start a broker process to handle open() inside the sandbox.
- // |broker_sandboxer_callback| is a callback that will enable a suitable
- // sandbox for the broker process itself.
+ // |broker_sandboxer_allocator| is a function pointer which can allocate a
+ // suitable sandbox policy for the broker process itself.
// |read_whitelist_extra| and |write_whitelist_extra| are lists of file
// names that should be whitelisted by the broker process, in addition to
const std::vector<std::string>& write_whitelist_extra);
« no previous file with comments | « content/common/sandbox_linux/bpf_cros_arm_gpu_policy_linux.cc ('k') | content/common/sandbox_linux/bpf_gpu_policy_linux.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698